	include "defs.i"

	SECTION code, CODE	

startup:
	; Find our task
	move.l	execbase, a6
	sub.l	a1, a1			; a1 = task (null = current)
	jsr	_LVOFindTask(a6)
	move.l	d0, curtask
	beq	.error

	; Set maxium priority
	move.l	curtask, a1		; a1 = task
	moveq	#127, d0		; d0 = priority
	jsr	_LVOSetTaskPri(a6)

        ; Retrieve vector base register
        btst.b  #AFB_68010, eb_AttnFlags+1(a6)
        beq.s   .not68010
        lea.l   .getvectorbase(pc), a5
        jsr     _LVOSupervisor(a6)
.not68010:
        ; leave vectorbase as 0

	; Open graphics.library
	lea	gfxname, a1		; a1 = name
	moveq	#0, d0			; d0 = version (0 = any)
	jsr	_LVOOpenLibrary(a6)
	move.l	d0, gfxbase
	beq	.error

	move.l  gfxbase, a6

        ; Grab topaz.8
        lea.l   topazattr(pc), a0
        jsr     _LVOOpenFont(a6)
        tst.l   d0
        beq     .error
        move.l  d0, a0
        move.l  d0, topazfont
        move.l  tf_CharData(a0), topazdata

	; Save WB view
	move.l	gb_ActiView(a6), oldview

	jsr	_LVOWaitTOF(a6)	
	; Clear view
	sub.l	a1, a1
	jsr	_LVOLoadView(a6)
	; Wait twice in case the previous mode was interlaced
	jsr	_LVOWaitTOF(a6)	
	jsr	_LVOWaitTOF(a6)

	; Save interrupt settings
	move.w	intenar+custom, oldintena
	; Disable dma
	move.w	#$7fff, intena+custom

	; Save DMA settings
	move.w	dmaconr+custom, olddma
	; Disable DMA
	move.w	#$7fff, dmacon+custom

	; Check for AGA
	btst	#9, vposr+custom
	sne.b	agapresent

        ; Call main
	move.l	#custom, a6
	jsr	main

	; Restore DMA settings
	move.w	olddma, d0
	or.w	#$8000, d0
	move.w	d0, dmacon+custom

	; Restore interrupt settings
	move.w	oldintena, d0
	or.w	#$8000, d0
	move.w	d0, intena+custom

	; Restore old WB view
	move.l	oldview, a1
	move.l	gfxbase, a6
	jsr	_LVOLoadView(a6)
	; Restart old copper list
	move.l	gb_copinit(a6), custom+cop1lc

        ; CloseFont
        move.l  topazfont, a1
        jsr     _LVOCloseFont(a6)

	; Close graphics.library
	move.l	a6, a1
	move.l	execbase, a6
	jsr	_LVOCloseLibrary(a6)

        moveq   #0, d0
	rts

.error:
	moveq	#1, d0
	rts

.getvectorbase:
        dc.w    $4e7a, $8801 ;movec   vbr, a0
        move.l	a0, vectorbase
        rte

	SECTION initdata, DATA

topazattr:
        dc.l topazname  ; ta_Name
        dc.w 8          ; ta_YSize
        dc.b 0, 0       ; ta_Stle, ta_Flags

topazname:
        dc.b 'topaz.font', 0
gfxname:
	dc.b 'graphics.library', 0
	even

	SECTION bss, BSS
curtask:
	ds.l 1
gfxbase:
	ds.l 1
oldview:
	ds.l 1
olddma:
	ds.w 1
oldintena:
	ds.w 1
vectorbase: ; Vector Base Register ($0.w for 68000, special register for 68010+)
        ds.l 1
agapresent:
	ds.b 1
	even
topazfont:
        ds.l 1
topazdata:
        ds.l 1
